@@ -63,7 +63,7 @@ class DiscreteEnv(gym.Env):
     self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
-    self.horizon=20
+    self.horizon=40
     
     
 
@@ -78,14 +78,17 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
-    
+    #check if horizon is over, otherwise keep on doing
+    end = bool(self.horizon <= 0)
+    if end:
+        done = True
+      
     data = []
-    for self.state in self.df.itertuples(index=False):    #self.df.itertuples(index=False):
+    for self.state in self.dfa.itertuples(index=False):    #self.df.itertuples(index=False):
       Xs = self.state[0]
       Xa = self.state[1]
       Y = self.state[2]
-      Xsa=(self.thetas[0])+(self.thetas[1])*(Xs)+(self.thetas[2])*(Xa)
+      Xsa=(self.thetasa[0])+(self.thetasa[1])*(Xs)+(self.thetasa[2])*(Xa)
       rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
       g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
       if (rho2>0.2) or (action == 1):
@@ -107,22 +110,13 @@ class DiscreteEnv(gym.Env):
     Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
 
     self.Ynew_cumul = np.mean(Prob1)
+    reward = self.Ynew_cumul
+               
+    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
+ 
     #reduce the horizon
     self.horizon -= 1
     
-      
-    #if done:
-      #reward = self.Ynew_cumul 
-    
-    done = bool(self.horizon <= 0)
-    reward = self.Ynew_cumul
-       
-    #check if horizon is over, otherwise keep on doing
-    if self.horizon <= 0:
-        done = True
-    else:
-        done = False
-
     #set placeholder for infos
     info ={}        
      
@@ -130,8 +124,18 @@ class DiscreteEnv(gym.Env):
 
 #reset state and horizon    
   def reset(self):
-    self.state= self.df.sample(n=1, random_state=1).values.reshape(3,) 
-    self.horizon = 20
+    self.horizon = 200
+    
+    self.dfa = pd.DataFrame(dict(
+            Xs=truncnorm.rvs(a=0, b= math.inf,size=self.size),
+            Xa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
+            Y=np.random.binomial(1, 0.5, self.size)))
+    self.model = LogisticRegression().fit(self.dfa[["Xs", "Xa"]], np.ravel(self.dfa[["Y"]].astype(int)))
+
+    #extract theta parameters from the fitted logistic
+    self.thetasa = np.array([self.modela.coef_[0,0] , self.modela.coef_[0,1], self.modela.intercept_[0]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
+    
+    self.state= self.dfa.sample(n=1, random_state=1).values.reshape(3,)     
     return self.state
 
 
